@@ -1,11 +1,11 @@
 /*
-  $Id: StringOps.h 15844 2013-03-28 17:40:24Z sloot $
+  $Id: StringOps.h 17575 2014-08-28 14:34:22Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/include/ticcutils/StringOps.h $
 
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2014
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of ticcutils
 
   ticcutils is free software; you can redistribute it and/or modify
@@ -45,14 +45,17 @@ namespace TiCC {
   std::string lowercase( const std::string& );
   std::string uppercase( const std::string& );
 
-  size_t split_at( const std::string&, std::vector<std::string>&, 
+  bool match_front( const std::string&, const std::string& );
+  bool match_back( const std::string&, const std::string& );
+
+  size_t split_at( const std::string&, std::vector<std::string>&,
 		   const std::string& );
-  size_t split_at_first_of( const std::string&, std::vector<std::string>&, 
+  size_t split_at_first_of( const std::string&, std::vector<std::string>&,
 			    const std::string& );
   inline size_t split( const std::string& s, std::vector<std::string>& vec ){
     return split_at_first_of( s, vec, " \r\t\n" );
   }
-  
+
   std::string format_nonascii( const std::string& );
 
   template< typename T >
@@ -65,19 +68,19 @@ namespace TiCC {
     }
     return result;
   }
-  
+
   template<>
-    inline bool stringTo<bool>( const std::string& str ) { 
+    inline bool stringTo<bool>( const std::string& str ) {
     std::string b = TiCC::uppercase( str );
-    if ( b == "YES" || b == "TRUE" || b == "1" ) 
-      return true; 
-    else if ( b == "FALSE" || b == "NO" || b == "0" ) 
-      return false; 
+    if ( b == "YES" || b == "TRUE" || b == "1" )
+      return true;
+    else if ( b == "FALSE" || b == "NO" || b == "0" )
+      return false;
     else
-      throw( std::runtime_error( "conversion from string '" 
-				 + str + "' to bool failed" ) ); 
-  } 
-  
+      throw( std::runtime_error( "conversion from string '"
+				 + str + "' to bool failed" ) );
+  }
+
   template< typename T >
     bool stringTo( const std::string& str, T& result ) {
     try {
@@ -103,16 +106,19 @@ namespace TiCC {
       return false;
     }
   }
-  
+
   template< typename T >
     std::string toString ( const T& obj, bool=false ) {
     std::stringstream dummy;
     if ( !( dummy << obj ) ) {
-      throw( std::runtime_error( "conversion to long string failed" ) );
+      throw( std::runtime_error( "conversion failed" ) );
     }
    return dummy.str();
   }
-  
+
+  std::string basename( const std::string& );
+  std::string dirname( const std::string& );
+
 }
 
 #endif
