@@ -1,11 +1,11 @@
 /*
-  $Id: StringOps.cxx 15564 2013-01-07 14:25:32Z sloot $
+  $Id: StringOps.cxx 17575 2014-08-28 14:34:22Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/src/StringOps.cxx $
 
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2014
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of ticcutils
 
   ticcutils is free software; you can redistribute it and/or modify
@@ -34,18 +34,26 @@
 
 #include <cerrno>
 #include <cfloat>
+#include "ticcutils/Version.h"
 #include "ticcutils/StringOps.h"
 
 using namespace std;
 namespace TiCC {
-  
+
+  string BuildInfo() {
+    // cannot be defined in the header becaus otherwise __DATE__ ans
+    // __TIME__ would be dynamic. (changing every time it is included)
+    return VersionName() + "-" + Version() + ". Compiled on "
+      + __DATE__ + " " + __TIME__;
+  }
+
   string trim( const string& s, const string& chars ){
     // remove leading and trailing characters from a string
     string result;
     if ( !s.empty() ){
       string::size_type b_pos = s.find_first_not_of( chars );
       if ( b_pos == string::npos )
-	return result;
+	return result; // 'empty' string. only garbage
       string::size_type e_pos = s.find_last_not_of( chars );
       if ( e_pos == string::npos )
 	result = s.substr( b_pos );
@@ -54,7 +62,7 @@ namespace TiCC {
     }
     return result;
   }
-  
+
   string trim_front( const string& s, const string& chars ){
     // remove leading characters from a string
     string result;
@@ -65,7 +73,7 @@ namespace TiCC {
     }
     return result;
   }
-  
+
   string trim_back( const string& s, const string& chars ){
     // remove trailing characters from a string
     string result;
@@ -76,14 +84,14 @@ namespace TiCC {
     }
     return result;
   }
-  
+
   static int toLower( const int& i ){ return tolower(i); }
   static int toUpper( const int& i ){ return toupper(i); }
-  
+
   void to_lower( string& s ){
     transform( s.begin(), s.end(), s.begin(), toLower );
   }
-  
+
   void to_upper( string& s ){
     transform( s.begin(), s.end(), s.begin(), toUpper );
   }
@@ -93,14 +101,30 @@ namespace TiCC {
     to_lower( result );
     return result;
   }
-  
+
   string uppercase( const string& s ){
     string result = s;
     to_upper( result );
     return result;
   }
 
-  size_t split_at( const string& src, vector<string>& results, 
+  bool match_back( const std::string& s, const std::string& tail ){
+    string::size_type pos = s.rfind( tail );
+    if ( pos != string::npos && (s.length() - pos == tail.length() ) ){
+      return true;
+    }
+    return false;
+  }
+
+  bool match_front( const std::string& s, const std::string& head ){
+    string::size_type pos = s.find( head );
+    if ( pos == 0  ){
+      return true;
+    }
+    return false;
+  }
+
+  size_t split_at( const string& src, vector<string>& results,
 		   const string& sep ){
     // split a string into substrings, using seps as seperator
     // silently skip empty entries (e.g. when two or more seperators co-incide)
@@ -123,7 +147,7 @@ namespace TiCC {
     return results.size();
   }
 
-  size_t split_at_first_of( const string& src, vector<string>& results, 
+  size_t split_at_first_of( const string& src, vector<string>& results,
 			    const string& seps ){
     // split a string into substrings, using the characters in seps
     // as seperators
@@ -146,8 +170,8 @@ namespace TiCC {
     }
     return results.size();
   }
-  
-  // format weird strings (like UTF8, LATIN1) printable 
+
+  // format weird strings (like UTF8, LATIN1) printable
   // useful for debugging
   string format_nonascii( const string& s ){
     stringstream os;
@@ -162,4 +186,20 @@ namespace TiCC {
     return os.str();
   }
 
+  std::string basename( const std::string& path ){
+    string::size_type pos = path.rfind( "/" );
+    if ( pos != string::npos )
+      return path.substr(pos+1);
+    else
+      return path;
+  }
+
+  std::string dirname( const std::string& path ){
+    string::size_type pos = path.rfind( "/" );
+    if ( pos != string::npos )
+      return path.substr(0,pos);
+    else
+      return ".";
+  }
+
 } // namespace TiCC
